@@ -1,4 +1,4 @@
-//@line 39 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 39 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
 
 /**
  * Communicator Shared Utility Library
@@ -128,9 +128,9 @@ function whereToOpenLink( e, ignoreButton, ignoreAlt )
 
   // Don't do anything special with right-mouse clicks.  They're probably clicks on context menu items.
 
-//@line 171 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 171 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
   if (ctrl || (middle && middleUsesTabs)) {
-//@line 173 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 173 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
     if (shift)
       return "tabshifted";
     else
@@ -346,9 +346,9 @@ function isBidiEnabled() {
 
 function openAboutDialog()
 {
-//@line 401 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 401 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
   window.openDialog("chrome://browser/content/aboutDialog.xul", "About", "centerscreen,chrome,resizable=no");
-//@line 403 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 403 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
 }
 
 function openPreferences(paneID, extraArgs)
@@ -395,7 +395,28 @@ function openReleaseNotes()
   openUILinkIn(relnotesURL, "tab");
 }
 
-//@line 471 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 450 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+/**
+ * Opens the update manager and checks for updates to the application.
+ */
+function checkForUpdates()
+{
+  var um = 
+      Components.classes["@mozilla.org/updates/update-manager;1"].
+      getService(Components.interfaces.nsIUpdateManager);
+  var prompter = 
+      Components.classes["@mozilla.org/updates/update-prompt;1"].
+      createInstance(Components.interfaces.nsIUpdatePrompt);
+
+  // If there's an update ready to be applied, show the "Update Downloaded"
+  // UI instead and let the user know they have to restart the browser for
+  // the changes to be applied. 
+  if (um.activeUpdate && um.activeUpdate.state == "pending")
+    prompter.showUpdateDownloaded(um.activeUpdate);
+  else
+    prompter.checkForUpdates();
+}
+//@line 471 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
 
 function buildHelpMenu()
 {
@@ -404,10 +425,56 @@ function buildHelpMenu()
   if (typeof safebrowsing != "undefined")
     safebrowsing.setReportPhishingMenu();
 
-//@line 529 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
-  // Needed by safebrowsing for inserting its menuitem so just hide it
-  document.getElementById("updateSeparator").hidden = true;
-//@line 532 "/export/home/ffslavex/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+//@line 480 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
+  var updates = 
+      Components.classes["@mozilla.org/updates/update-service;1"].
+      getService(Components.interfaces.nsIApplicationUpdateService);
+  var um = 
+      Components.classes["@mozilla.org/updates/update-manager;1"].
+      getService(Components.interfaces.nsIUpdateManager);
+
+  // Disable the UI if the update enabled pref has been locked by the 
+  // administrator or if we cannot update for some other reason
+  var checkForUpdates = document.getElementById("checkForUpdates");
+  var canUpdate = updates.canUpdate;
+  checkForUpdates.setAttribute("disabled", !canUpdate);
+  if (!canUpdate)
+    return; 
+
+  var strings = document.getElementById("bundle_browser");
+  var activeUpdate = um.activeUpdate;
+  
+  // If there's an active update, substitute its name into the label
+  // we show for this item, otherwise display a generic label.
+  function getStringWithUpdateName(key) {
+    if (activeUpdate && activeUpdate.name)
+      return strings.getFormattedString(key, [activeUpdate.name]);
+    return strings.getString(key + "Fallback");
+  }
+  
+  // By default, show "Check for Updates..."
+  var key = "default";
+  if (activeUpdate) {
+    switch (activeUpdate.state) {
+    case "downloading":
+      // If we're downloading an update at present, show the text:
+      // "Downloading Firefox x.x..." otherwise we're paused, and show
+      // "Resume Downloading Firefox x.x..."
+      key = updates.isDownloading ? "downloading" : "resume";
+      break;
+    case "pending":
+      // If we're waiting for the user to restart, show: "Apply Downloaded
+      // Updates Now..."
+      key = "pending";
+      break;
+    }
+  }
+  checkForUpdates.label = getStringWithUpdateName("updatesItem_" + key);
+  if (um.activeUpdate && updates.isDownloading)
+    checkForUpdates.setAttribute("loading", "true");
+  else
+    checkForUpdates.removeAttribute("loading");
+//@line 532 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/utilityOverlay.js"
 }
 
 function isElementVisible(aElement)
